@@ -55,6 +55,7 @@
 
 #define RCFILE_PATH DATADIR "/" PACKAGE_NAME "/ec_style.rc"
 #define GFXDIR DATADIR "/pixmaps/" PACKAGE_NAME "/"
+#define ECOACH_DATADIR "/media/mmc2/Ecoach"
 
 /*****************************************************************************
  * Private function prototypes                                               *
@@ -149,7 +150,10 @@ AppData *interface_create()
 
 	/* Initialize GConf helper */
 	interface_initialize_gconf(app_data);
-
+	
+	/* Create default datafolder media/mmc2/Ecoach */
+	g_mkdir(ECOACH_DATADIR,0700);
+	
 	/* Initialize generic settings */
 	app_data->settings = settings_initialize(app_data->gconf_helper);
 
@@ -240,7 +244,7 @@ AppData *interface_create()
 	gconf_helper_add_key_string(
 			app_data->gconf_helper,
 			ECGC_DEFAULT_FOLDER,
-			"",
+			"/media/mmc2/Ecoach/",
 			interface_default_folder_changed,
 			app_data,
 			NULL);
@@ -363,10 +367,10 @@ static void interface_create_menu(AppData *app_data)
 			path_level_1,
 			_("Maximum\nheart rate"),
 			GFXDIR "menu_max_heart_btn",
-			NULL,
-			NULL,
+			show_calculate_maxheartrate,
+			app_data,
 			TRUE);
-
+	/*
 	navigation_menu_item_new_for_path(
 			app_data->navigation_menu,
 			path_level_2,
@@ -374,16 +378,16 @@ static void interface_create_menu(AppData *app_data)
 			GFXDIR "menu_calculate_btn",
 			show_calculate_maxheartrate,
 			app_data,
-			FALSE);
+			FALSE);*/
 
-	navigation_menu_item_new_for_path(
+	/*navigation_menu_item_new_for_path(
 			app_data->navigation_menu,
 			path_level_2,
 			_("Test"),
 			NULL,
 			NULL,
 			NULL,
-			FALSE);
+			FALSE);*/
 
 	gtk_tree_path_free(path_level_2);
 
@@ -525,7 +529,7 @@ static void interface_default_folder_changed(
 
 	value = gconf_entry_get_value(entry);
 	default_folder_name = gconf_value_get_string(value);
-
+	
 	activity_chooser_set_default_folder(
 			app_data->activity_chooser,
 			default_folder_name);
