@@ -63,7 +63,7 @@
  * Definitions                                                               *
  *****************************************************************************/
 
-#define MAPTILE_LOADER_EXEC_NAME "maptile-loader"
+#define MAPTILE_LOADER_EXEC_NAME "ecoach-maptile-loader"
 #define GFXDIR DATADIR "/pixmaps/ecoach/"
 
 #define MAP_VIEW_SIMULATE_GPS 0
@@ -174,7 +174,9 @@ MapView *map_view_new(
 
 	self->map_widget_state = MAP_VIEW_MAP_WIDGET_STATE_NOT_CONFIGURED;
 	self->has_gps_fix = FALSE;
-	self->metric = TRUE;
+	
+	
+
 
 	/* Main layout item		*/
 	self->main_widget = gtk_fixed_new();
@@ -461,27 +463,58 @@ MapView *map_view_new(
 			0, 0);
 
 	/* Traveled distance		*/
+	if(self->metric)
+	{
 	self->info_distance = map_view_create_info_button(
 			self,
 			_("Distance"),
 			_("0 m"),
 			1, 0);
+	}
+	else
+	{
+		self->info_distance = map_view_create_info_button(
+				self,
+				_("Distance"),
+				_("0 ft"),
+				1, 0);	
+	}
 
 	/* Speed			*/
+	if(self->metric)
+	{
 	self->info_speed = map_view_create_info_button(
 			self,
 			_("Speed"),
 			_("0.0 km/h"),
 			0, 1);
-	
+	}
+	else
+	{
+	self->info_speed = map_view_create_info_button(
+				self,
+				_("Speed"),
+				_("0.0 mph"),0, 1);
+	}
 	
 
 	/* Average speed		*/
+	if(self->metric)
+	{
 	self->info_avg_speed = map_view_create_info_button(
 			self,
 			_("Avg. speed"),
 			_("0.0 km/h"),
 			1, 1);
+	}
+	else
+	{
+	self->info_avg_speed = map_view_create_info_button(
+			self,
+    			_("Avg. speed"),
+			_("0.0 mph"),
+			1, 1);	
+	}
 
 	/* Heart rate			*/
 	self->info_heart_rate = map_view_create_info_button(
@@ -491,13 +524,13 @@ MapView *map_view_new(
 			0, 2);
 
 	self->pxb_hrm_status[MAP_VIEW_HRM_STATUS_LOW] =
-		map_view_load_image(GFXDIR "ec_icon_heart_red.png");
+		map_view_load_image(GFXDIR "ec_icon_heart_yellow.png");
 
 	self->pxb_hrm_status[MAP_VIEW_HRM_STATUS_GOOD] =
 		map_view_load_image(GFXDIR "ec_icon_heart_green.png");
 
 	self->pxb_hrm_status[MAP_VIEW_HRM_STATUS_HIGH] =
-		map_view_load_image(GFXDIR "ec_icon_heart_yellow.png");
+		map_view_load_image(GFXDIR "ec_icon_heart_red.png");
 
 	self->pxb_hrm_status[MAP_VIEW_HRM_STATUS_NOT_CONNECTED] =
 		map_view_load_image(GFXDIR "ec_icon_heart_grey.png");
@@ -505,13 +538,6 @@ MapView *map_view_new(
 	ec_button_set_icon_pixbuf(EC_BUTTON(self->info_heart_rate),
 			self->pxb_hrm_status[MAP_VIEW_HRM_STATUS_NOT_CONNECTED]
 			);
-	/* Distance unit */
-	
-	self->info_units = map_view_create_info_button(self,
-			 _("Units"), _("Metric"), 1, 2);
-	g_signal_connect(G_OBJECT(self->info_units), "clicked",
-			 G_CALLBACK(map_view_units_clicked), self);
-	
 	/* GPS device			*/
 #if (MAP_VIEW_SIMULATE_GPS)
 	self->show_map_widget_handler_id = 1;
@@ -578,6 +604,16 @@ void map_view_show(MapView *self)
 {
 	g_return_if_fail(self != NULL);
 	DEBUG_BEGIN();
+	
+	if(gconf_helper_get_value_bool_with_default(self->gconf_helper,
+	   USE_METRIC,TRUE))
+	{
+		self->metric = TRUE;
+	}
+	else
+	{
+		self->metric = FALSE;
+	}
 
 	if(!self->beat_detector_connected)
 	{
@@ -926,7 +962,7 @@ static void map_view_heart_rate_changed(
 	g_return_if_fail(time != NULL);
 	DEBUG_BEGIN();
 
-	if(heart_rate > 0)
+	if(heart_rate >= 0)
 	{
 		text = g_strdup_printf(_("%d bpm"), (gint)heart_rate);
 		ec_button_set_label_text(
@@ -1035,10 +1071,17 @@ static void map_view_location_changed(
 	MapPoint point;
 	MapView *self = (MapView *)user_data;
 	gboolean map_widget_ready = TRUE;
-
+	
 	g_return_if_fail(self != NULL);
 	DEBUG_BEGIN();
 
+	/* Keep display on */
+	if(gconf_helper_get_value_bool_with_default(self->gconf_helper,
+						    DISPLAY_ON,TRUE)) {
+		osso_display_state_on(self->osso);
+		osso_display_blanking_pause(self->osso);
+	}
+
 	DEBUG("Latitude: %.2f - Longitude: %.2f\nAltitude: %.2f\n",
 			device->fix->latitude,
 			device->fix->longitude,
@@ -1082,6 +1125,9 @@ static void map_view_location_changed(
 	} else {
 		DEBUG("Latitude and longitude are not valid");
 	}
+	if(device->status == LOCATION_GPS_DEVICE_STATUS_NO_FIX) {
+		hildon_banner_show_information(GTK_WIDGET(self->parent_window), NULL, "No GPS fix!");
+	}
 
 	DEBUG_END();
 }
@@ -1545,7 +1591,7 @@ static void map_view_pause_activity(MapView *self)
 	util_add_time(&self->elapsed_time, &result, &self->elapsed_time);
 
 	map_view_set_elapsed_time(self, &self->elapsed_time);
-	map_view_update_stats(self);
+//	map_view_update_stats(self);
 
 	g_source_remove(self->activity_timer_id);
 	self->activity_timer_id = 0;
